pub struct ZstdStreamDecoder<R: Read> { /* private fields */ }Expand description
Streaming Zstandard decoder that implements Read.
All compressed data is read eagerly from the inner reader on the first
read call, decompressed into an internal buffer, and then served from
that buffer for subsequent reads.
Implementations
Sourceimpl<R: Read> ZstdStreamDecoder<R>
impl<R: Read> ZstdStreamDecoder<R>
Sourcepub fn with_dictionary(reader: R, dict: Vec<u8>) -> Self
pub fn with_dictionary(reader: R, dict: Vec<u8>) -> Self
Create a new streaming decoder with a dictionary.
Dictionary-based decompression requires the same dictionary that was used during compression.
Sourcepub fn decompressed_size(&self) -> usize
pub fn decompressed_size(&self) -> usize
Returns the total number of decompressed bytes available (including
bytes already consumed via read).
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
Returns true if all decompressed data has been read.